library(psych)
library(reshape)
library(dplyr)
library(ggplot2)
library(afex)
library(pastecs)
library(car)

df <- read.csv("fitts.csv")
df$A <- factor(df$A)
df$W <- factor(df$W)
#df$Block <- factor(df$Block)

save(df, file = "fitts.RData")

grouped <- group_by(df, Participant)
df.grouped <- summarize(grouped, Throughput = mean(Throughput))

# Visually checking distribution for normality
ggplot(df.grouped, aes(x = Throughput)) + 
  geom_histogram(aes(y = ..density..), binwidth = .5, colour = "black", fill = "#C0C0C0") +
  geom_density(alpha = .2, fill = "#6699FF") +
  theme_bw()

# Q-Q plot - if normal, it should be on a straight line
qplot(sample = df.grouped$Throughput, stat = "qq") + theme_bw()

stat.desc(x = df.grouped$Throughput, basic = FALSE, desc = TRUE, norm = FALSE)
# Shapiro-Wilk test of normality
stat.desc(x = df.grouped$Throughput, basic = FALSE, desc = FALSE, norm = TRUE)

dfM <- filter(df, Condition == "Mouse")
dfS <- filter(df, Condition == "Space")

dir.create("./plots")


plot_distribution <- function(df, condition) {
  for (i in unique(df$Block)) { # could be rewritten with "by" function
    d <- filter(dfM, Block == i)
    
    p <- ggplot(d, aes(x = Throughput)) + 
      geom_histogram(aes(y = ..density..), binwidth = .5, colour = "black", fill = "#C0C0C0") +
      geom_density(alpha = .2, fill = "#6699FF") +
      ggtitle(paste("Group = ", i)) +
      theme_bw(base_size = 20)
    
    plot.name <- sprintf("%s%s%s", "./plots/", i, paste("_", condition, ".pdf"))
    pdf(plot.name)
    print(p)
    dev.off()
  } 
}

print_normality <- function(df, condition) {
  print(paste("Normality tests for ", condition))
  print("=============================")
  for (i in unique(df$Block)) {
    d <- filter(dfM, Block == i)
    
    s <- stat.desc(x = d$Throughput, basic = FALSE, desc = FALSE, norm = TRUE)
    print(paste("Normality tests for Group", i))
    print(round(s, digits = 3))
    print("")
  } 
}

plot_distribution(dfM, "mouse")
plot_distribution(dfS, "space")

print_normality(dfS, "mouse")
print_normality(dfS, "space")

leveneTest(y = dfM$Throughput, group = dfM$Block, center = mean)
leveneTest(y = dfS$Throughput, group = dfS$Block, center = mean)

# Dealing with Outliers 
boxplot(dfM$Throughput ~ dfM$Block)

out <- boxplot(dfM$Throughput ~ dfM$Block, plot = FALSE)$out
print(out)

outParticipants <- dfM$Participant[dfM$Throughput %in% out]
print(outParticipants)

# Remove the outliers from the data
dfMclean <- filter(dfM, !dfM$Participant %in% outParticipants)

# Replace the outlying values
dfM <- dfM %>% mutate(Throughput = replace(Throughput, 
                                           dfM$Throughput %in% out, 
                                           mean(dfM$Throughput) + 2 * sd(dfM$Throughput)))

# ANOVA
fit <- aov_ez(data = dfM,
              id = "Participant",
              dv = "Throughput",
              within = "Block")
fit

save(df, file = "fitts.RData")
